@@ -15,7 +15,7 @@ import LawfulConversions.Relations.DayAndString ()
 
 -- | Implements ISO-8601.
 instance IsSome Data.Text.Encoding.StrictTextBuilder Day where
-  to = from . to @String
+  to = onfrom . to @String
   maybeFrom = maybeFrom @String . to
 
 #elif MIN_VERSION_text(2,0,2)
@@ -30,7 +30,7 @@ import LawfulConversions.Relations.DayAndString ()
 
 -- | Implements ISO-8601.
 instance IsSome Data.Text.Encoding.StrictBuilder Day where
-  to = from . to @String
+  to = onfrom . to @String
   maybeFrom = maybeFrom @String . to
 
 #endif
