@@ -17,4 +17,4 @@ instance IsSome Data.ByteString.Lazy.ByteString Data.Text.Text where
 
 -- | Lenient UTF-8 decoding.
 instance IsMany Data.ByteString.Lazy.ByteString Data.Text.Text where
-  from = Data.Text.Lazy.toStrict . Data.Text.Lazy.Encoding.decodeUtf8With Data.Text.Encoding.Error.lenientDecode
+  onfrom = Data.Text.Lazy.toStrict . Data.Text.Lazy.Encoding.decodeUtf8With Data.Text.Encoding.Error.lenientDecode
